@@ -170,3 +170,6 @@ class DSRequest(RPCRequest):
         else:
             ids = [0]
         return [id for id in ids if id is not None]
+
+    def __str__(self):
+        return str(self.__dict__)
