@@ -19,56 +19,6 @@ from isc_common.http.response import JsonResponse
 logger = logging.getLogger(__name__)
 
 
-def JsonResponseWithException(printing=False, printing_res=False):
-    class JE:
-        def __init__(self, func):
-            self.func = func
-            self.pp = pprint.PrettyPrinter(indent=4)
-
-        def print(self, o, str=None):
-            if str:
-                print(f"=========== Begin {str} ========================")
-            else:
-                print(f"=========== Begin {o.__class__.__name__} ========================")
-            if isinstance(o, dict):
-                self.pp.pprint(RequestData(o).getDataWithOutField(['pp', '_state']).dict())
-            elif isinstance(o, object):
-                self.pp.pprint(RequestData(o.__dict__).getDataWithOutField(['pp', '_state']).dict())
-
-            if str:
-                print(f"=========== End   {str} ========================")
-            else:
-                print(f"=========== End   {o.__class__.__name__} ========================")
-            print("\n")
-
-        def __call__(self, *args, **kwargs):
-            try:
-                if printing:
-                    request = args[0]
-                    _request = DSRequest(request)
-                    self.print(_request)
-                    self.print(request.COOKIES, 'request.COOKIES')
-                    self.print(request.GET, 'request.GET')
-                    self.print(request.POST, 'request.POST')
-                    self.print(request.META, 'request.META')
-
-                res = self.func(*args, **kwargs)
-                if printing_res:
-                    self.print(res)
-                return res
-            except Exception as ex:
-                exc_info = sys.exc_info()
-                stackTrace = traceback.format_exception(*exc_info)
-                message = str(ex)
-                for x in stackTrace:
-                    logger.error(x)
-
-                del exc_info
-
-                return JsonResponse(DSResponseFailure(message=message, stackTrace=stackTrace).response)
-
-    return JE
-
 def JsonWSResponseWithException(printing=False, printing_res=False):
     class JE:
         def __init__(self, func):
@@ -163,7 +113,8 @@ def JsonWSResponseWithException(printing=False, printing_res=False):
 
     return JE
 
-def JsonWSPostResponseWithException(printing=False, printing_res=False):
+
+def JsonResponseWithException(printing=False, printing_res=False):
     class JE:
         def __init__(self, func):
             self.func = func
@@ -186,28 +137,9 @@ def JsonWSPostResponseWithException(printing=False, printing_res=False):
             print("\n")
 
         def __call__(self, *args, **kwargs):
-            request = args[0]
-
-            self.port = request.POST.get('ws_port')
-            if not self.port:
-                self.port = request.session._session.get('ws_port')
-                if not self.port:
-                    raise Exception(Common.arraund_error('Do not have ws_port'))
-
-            self.host = request.POST.get('ws_host')
-            if not self.host:
-                self.host = request.session._session.get('host')
-                if not self.host:
-                    raise Exception(Common.arraund_error('Do not have ws_host'))
-
-            self.channel = request.POST.get('ws_channel')
-            if not self.channel:
-                self.channel = request.session._session.get('ws_channel')
-                if not self.channel:
-                    raise Exception(Common.arraund_error('Do not have ws_channel'))
-
             try:
                 if printing:
+                    request = args[0]
                     _request = DSRequest(request)
                     self.print(_request)
                     self.print(request.COOKIES, 'request.COOKIES')
@@ -218,38 +150,109 @@ def JsonWSPostResponseWithException(printing=False, printing_res=False):
                 res = self.func(*args, **kwargs)
                 if printing_res:
                     self.print(res)
-
                 return res
             except Exception as ex:
                 exc_info = sys.exc_info()
                 stackTrace = traceback.format_exception(*exc_info)
                 message = str(ex)
-
-                try:
-                    ws = create_connection(f"ws://{self.host}:{self.port}/ws/{self.channel}/")
-                    ws.send(json.dumps(dict(message=message, stackTrace=stackTrace, type="error")))
-                    ws.close()
-                except Exception as ex:
-
-                    exc_info = sys.exc_info()
-                    message = str(ex)
-                    stackTrace = traceback.format_exception(*exc_info)
-
-                    logging.error(message)
-
-                    for x in stackTrace:
-                        logger.error(x)
-
-                    del exc_info
-
                 for x in stackTrace:
                     logger.error(x)
 
-                return JsonResponse(DSResponseOk().response)
+                del exc_info
+
+                return JsonResponse(DSResponseFailure(message=message, stackTrace=stackTrace).response)
 
     return JE
 
 
+def JsonWSPostResponseWithException(printing=False, printing_res=False):
+    return JsonResponseWithException(printing=printing, printing_res=printing_res)
+    # class JE:
+    #     def __init__(self, func):
+    #         self.func = func
+    #         self.pp = pprint.PrettyPrinter(indent=4)
+    #
+    #     def print(self, o, str=None):
+    #         if str:
+    #             print(f"=========== Begin {str} ========================")
+    #         else:
+    #             print(f"=========== Begin {o.__class__.__name__} ========================")
+    #         if isinstance(o, dict):
+    #             self.pp.pprint(RequestData(o).getDataWithOutField(['pp', '_state']).dict())
+    #         elif isinstance(o, object):
+    #             self.pp.pprint(RequestData(o.__dict__).getDataWithOutField(['pp', '_state']).dict())
+    #
+    #         if str:
+    #             print(f"=========== End   {str} ========================")
+    #         else:
+    #             print(f"=========== End   {o.__class__.__name__} ========================")
+    #         print("\n")
+    #
+    #     def __call__(self, *args, **kwargs):
+    #         request = args[0]
+    #
+    #         self.port = request.POST.get('ws_port')
+    #         if not self.port:
+    #             self.port = request.session._session.get('ws_port')
+    #             if not self.port:
+    #                 raise Exception(Common.arraund_error('Do not have ws_port'))
+    #
+    #         self.host = request.POST.get('ws_host')
+    #         if not self.host:
+    #             self.host = request.session._session.get('host')
+    #             if not self.host:
+    #                 raise Exception(Common.arraund_error('Do not have ws_host'))
+    #
+    #         self.channel = request.POST.get('ws_channel')
+    #         if not self.channel:
+    #             self.channel = request.session._session.get('ws_channel')
+    #             if not self.channel:
+    #                 raise Exception(Common.arraund_error('Do not have ws_channel'))
+    #
+    #         try:
+    #             if printing:
+    #                 _request = DSRequest(request)
+    #                 self.print(_request)
+    #                 self.print(request.COOKIES, 'request.COOKIES')
+    #                 self.print(request.GET, 'request.GET')
+    #                 self.print(request.POST, 'request.POST')
+    #                 self.print(request.META, 'request.META')
+    #
+    #             res = self.func(*args, **kwargs)
+    #             if printing_res:
+    #                 self.print(res)
+    #
+    #             return res
+    #         except Exception as ex:
+    #             exc_info = sys.exc_info()
+    #             stackTrace = traceback.format_exception(*exc_info)
+    #             message = str(ex)
+    #
+    #             try:
+    #                 ws = create_connection(f"ws://{self.host}:{self.port}/ws/{self.channel}/")
+    #                 ws.send(json.dumps(dict(message=message, stackTrace=stackTrace, type="error")))
+    #                 ws.close()
+    #             except Exception as ex:
+    #
+    #                 exc_info = sys.exc_info()
+    #                 message = str(ex)
+    #                 stackTrace = traceback.format_exception(*exc_info)
+    #
+    #                 logging.error(message)
+    #
+    #                 for x in stackTrace:
+    #                     logger.error(x)
+    #
+    #                 del exc_info
+    #
+    #             for x in stackTrace:
+    #                 logger.error(x)
+    #
+    #             return JsonResponse(DSResponseOk().response)
+    #
+    # return JE
+
+
 class DSResponse(RPCResponse):
 
     def normal_round(self, n):
@@ -305,7 +308,7 @@ class DSResponse(RPCResponse):
 
         if isinstance(data, list):
 
-            if self.startRow is not None and self.endRow is not None :
+            if self.startRow is not None and self.endRow is not None:
                 qty = self.endRow - self.startRow
                 len_data = len(self.data)
 
@@ -325,9 +328,9 @@ class DSResponse(RPCResponse):
 
     @property
     def response(self):
-        setAttr(self.dict,'startRow', self.startRow)
-        setAttr(self.dict,'endRow', self.endRow)
-        setAttr(self.dict,'totalRows', self.totalRows)
+        setAttr(self.dict, 'startRow', self.startRow)
+        setAttr(self.dict, 'endRow', self.endRow)
+        setAttr(self.dict, 'totalRows', self.totalRows)
         # logger.debug(f'self.dict: {self.dict}')
         return dict(response=self.dict)
 
