@@ -1,6 +1,6 @@
 import logging
 
-from django.db.models import Model, BooleanField, BigAutoField, DateTimeField
+from django.db.models import Model, BooleanField, BigAutoField, DateTimeField, Transform, CharField, TextField
 from django.utils import timezone
 
 from isc_common.managers.common_manager import CommonManager, CommonQuerySet
@@ -69,15 +69,18 @@ class AuditModel(Model):
 
     @staticmethod
     def uncapitalize(str):
-        return str[0:1].lower() + str[1:]
+        from isc_common.common.functions import uncapitalize
+        return uncapitalize(str)
 
     @staticmethod
     def dbl_qutes_str(str):
-        return f'"{str}"'
+        from isc_common.common.functions import dbl_qutes_str
+        return dbl_qutes_str(str)
 
     @staticmethod
     def qutes_str(str):
-        return f"'{str}'"
+        from isc_common.common.functions import qutes_str
+        return qutes_str(str)
 
     @property
     def idHidden(self):
@@ -101,3 +104,17 @@ class AuditModel(Model):
 
     objects = AuditManager()
     all_objects = AuditManager(alive_only=False)
+
+class Dbl_spacesValue(Transform):
+    lookup_name = 'delete_dbl_spaces'
+    function = 'delete_dbl_spaces'
+
+CharField.register_lookup(Dbl_spacesValue)
+TextField.register_lookup(Dbl_spacesValue)
+
+class Trim_Value(Transform):
+    lookup_name = 'trim'
+    function = 'trim'
+
+CharField.register_lookup(Trim_Value)
+TextField.register_lookup(Trim_Value)
