@@ -1,6 +1,7 @@
 import logging
 
 from django.db.models.query import RawQuerySet
+
 from isc_common.http.DSRequest import DSRequest
 from isc_common.models.audit import AuditManager, AuditQuerySet
 
@@ -8,8 +9,11 @@ logger = logging.getLogger(__name__)
 
 
 class TreeAuditModelQuerySet(AuditQuerySet):
+    check_dliting = True
+
     def delete(self):
-        raise Exception('Удаление без проверки !!!!')
+        if self.check_dliting:
+            raise Exception('Удаление без проверки !!!!')
         return super().delete()
 
     def get_descendants(self,
@@ -77,7 +81,18 @@ class TreeAuditModelQuerySet(AuditQuerySet):
 
         return res
 
-    def get_parents(self, id=None, start=None, end=None, child_id='child_id', parent_id='parent_id', include_self=True, where_clause='', order_by_clause='', fields='*') -> RawQuerySet:
+    def get_parents(self,
+                    id=None,
+                    start=None,
+                    end=None,
+                    child_id='child_id',
+                    parent_id='parent_id',
+                    include_self=True,
+                    where_clause='',
+                    order_by_clause='',
+                    sql_text=None,
+                    fields='*'
+                    ) -> RawQuerySet:
         db_name = self.model._meta.db_table
 
         if isinstance(id, int):
