@@ -8,11 +8,13 @@ from django.utils import timezone
 from tqdm import tqdm
 
 from isc_common.bit import IsBitOff
+from isc_common.models.deleted_progresses import Deleted_progresses
 from isc_common.models.progresses import Progresses
 from isc_common.ws.progressStack import ProgressStack
 
 logger = logging.getLogger(__name__)
 
+progress_deleted = 'Прогресс удален.'
 
 class ProgressDroped(Exception):
     ...
@@ -28,6 +30,7 @@ def managed_progress(qty, user, id, message='Обработано позиций
         progress.close()
         if callable(progress.except_func):
             progress.except_func(progress)
+        Deleted_progresses.objects.filter(id_progress=id, user=user).delete()
         raise ex
     except Exception as ex:
         exc_info = sys.exc_info()
